from dataclasses import dataclass, field
from dacite import from_dict
import yaml
from pathlib import Path


def find_config(start: Path | None = None) -> Path | None:
    current = (start or Path.cwd()).resolve()

    for parent in [current, *current.parents]:
        candidate = parent / "zona.yml"
        if candidate.is_file():
            return candidate
    return None


@dataclass
class BlogConfig:
    dir: str = "blog"


@dataclass
class HighlightingConfig:
    enabled: bool = True
    theme: str = "ashen"
    wrap: bool = False


@dataclass
class MarkdownConfig:
    image_labels: bool = True
    syntax_highlighting: HighlightingConfig = field(
        default_factory=HighlightingConfig
    )


@dataclass
class ThemeConfig:
    name: str = "default"


@dataclass
class BuildConfig:
    clean_output_dir: bool = True
    include_drafts: bool = False


IGNORELIST = [".git", ".env", "*/.marksman.toml"]


@dataclass
class ZonaConfig:
    title: str = "Zona Blog"
    base_url: str = "https://example.com"
    language: str = "en"
    # list of globs relative to content that should be ignored
    ignore: list[str] = field(default_factory=lambda: IGNORELIST)
    markdown: MarkdownConfig = field(default_factory=MarkdownConfig)
    theme: ThemeConfig = field(default_factory=ThemeConfig)
    build: BuildConfig = field(default_factory=BuildConfig)
    blog: BlogConfig = field(default_factory=BlogConfig)

    @classmethod
    def from_file(cls, path: Path) -> "ZonaConfig":
        with open(path, "r") as f:
            raw = yaml.safe_load(f)
        return from_dict(data_class=cls, data=raw)
