from typing import NamedTuple
from rich import print
from importlib import resources
import fnmatch
from pathlib import Path
from shutil import copy2
import string


class ZonaResource(NamedTuple):
    name: str
    contents: str


def get_resources(subdir: str) -> list[ZonaResource]:
    """Load the packaged resources in data/subdir"""
    out: list[ZonaResource] = []
    for resource in (
        resources.files("zona").joinpath(f"data/{subdir}").iterdir()
    ):
        out.append(
            ZonaResource(f"{subdir}/{resource.name}", resource.read_text())
        )
    print(out)
    return out


def get_resource_dir(subdir: str) -> Path:
    dir = resources.files("zona").joinpath(f"data/{subdir}")
    with resources.as_file(dir) as path:
        assert isinstance(path, Path)
        assert path.is_dir()
        return path


def ensure_parents(target: Path):
    """Ensure the target's parent directories exist."""
    target.parent.mkdir(parents=True, exist_ok=True)


def copy_static_file(src: Path, dst: Path):
    """Copy a static file from one location to another."""
    ensure_parents(dst)
    copy2(src, dst)


def filename_to_title(path: Path) -> str:
    name = path.stem
    words = name.replace("-", " ").replace("_", " ")
    return string.capwords(words)


def normalize_url(url: str) -> str:
    if not url.startswith("/"):
        url = "/" + url
    return url


def should_ignore(path: Path, patterns: list[str], base: Path) -> bool:
    rel_path = path.relative_to(base)
    return any(fnmatch.fnmatch(str(rel_path), pattern) for pattern in patterns)
